==> nomachine-8.8.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXReverseClientDaemon.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXReverseClientDaemon;no warnings;((%monitor)=());((%monitorFD)=());sub 
handleConnection{(my $fd=shift (@_));(my $request=shift (@_));Logger::debug (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x48\x61\x6e\x64\x6c\x69\x6e\x67\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x66\x72\x6f\x6d\x20\x72\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$request)."\x27\x2e"));if (($request=~ /Reverse connection running for uuid=(.*) / )
){(my $uuid=$1);($monitor{$uuid}=$fd);($monitorFD{$fd}=$uuid);(my $caption=(
$uuid.
"\x20\x72\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x6d\x6f\x6e\x69\x74\x6f\x72"))
;(my $callback=
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x3a\x63\x61\x6c\x6c\x62\x61\x63\x6b"
);Common::NXSelector::changeCallback ($fd,$caption,$callback);
NXServerDaemon::removeFdFromSelector ($fd);return ((0x1747+  63-0x1785));}
Logger::warning (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x68\x61\x6e\x64\x6c\x65\x20\x72\x65\x76\x65\x72\x73\x65\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x72\x65\x71\x75\x65\x73\x74\x20\x27"
.$request)."\x27\x2e"));return ((0x038a+ 4741-0x160f));}sub callback{(my $fd=
shift (@_));(my $uuid=$monitorFD{$fd});my ($buffer);(my $bytes=main::nxread ($fd
,(\$buffer),65536));if (($bytes>(0x1f16+ 733-0x21f3))){Logger::warning (((((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x61\x64\x20\x27"
.$buffer).
"\x27\x20\x66\x72\x6f\x6d\x20\x74\x68\x65\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x27"
).$uuid)."\x27\x20\x46\x44\x23").$fd)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x27"
.$uuid)."\x27\x20\x63\x6c\x6f\x73\x65\x64\x20\x46\x44\x23").$fd)."\x2e"));
Common::NXSelector::removeFromGlobalSelector ($fd);main::nxclose ($fd);if ((
$monitor{$uuid}!=$fd)){Logger::debug (
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x4e\x65\x77\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x72\x75\x6e\x6e\x69\x6e\x67\x2e"
);return ((0x0118+ 3536-0x0ee8));}__setUnreachable ($uuid);($monitor{$uuid}=
undef);($monitorFD{$fd}=undef);delete ($monitor{$uuid});delete ($monitorFD{$fd})
;if ((not (NXServerDaemon::isTerminateMode ()))){
NXConnectionMonitor::propagateMap ();}}}sub checkStatus{(my $uuid=shift (@_));(my $connection
=$monitor{$uuid});if (defined ($monitor{$uuid})){Logger::debug (((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$uuid).
"\x27\x20\x69\x73\x20\x63\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x77\x69\x74\x68\x20\x46\x44"
).$connection)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$uuid).
"\x27\x20\x69\x6e\x20\x6e\x6f\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x65\x64\x2e"))
;__setUnreachable ($uuid);}}sub __setUnreachable{(my $uuid=shift (@_));(my (
@keys)=());(my (@args)=$uuid);(my $timeout=(-(0x0ba2+ 5066-0x1f6b)));
main::nxrequire ("\x4e\x58\x52\x65\x64\x69\x73\x53\x63\x72\x69\x70\x74");return 
(NXRedisScript::executeScript (
"\x73\x65\x74\x55\x6e\x72\x65\x61\x63\x68\x61\x62\x6c\x65",(\@keys),(\@args),
$timeout));}return ((0x1aa5+ 904-0x1e2c));

==> nomachine-8.9.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXReverseClientDaemon.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXReverseClientDaemon;no warnings;((%monitor)=());((%monitorFD)=());sub 
handleConnection{(my $fd=shift (@_));(my $request=shift (@_));Logger::debug (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x48\x61\x6e\x64\x6c\x69\x6e\x67\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x66\x72\x6f\x6d\x20\x72\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$request)."\x27\x2e"));if (($request=~ /Reverse connection running for uuid=(.*) / )
){(my $uuid=$1);($monitor{$uuid}=$fd);($monitorFD{$fd}=$uuid);(my $caption=(
$uuid.
"\x20\x72\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x6d\x6f\x6e\x69\x74\x6f\x72"))
;(my $callback=
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x3a\x63\x61\x6c\x6c\x62\x61\x63\x6b"
);Common::NXSelector::changeCallback ($fd,$caption,$callback);
NXServerDaemon::removeFdFromSelector ($fd);return ((0x0cba+ 6705-0x26ea));}
Logger::warning (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x68\x61\x6e\x64\x6c\x65\x20\x72\x65\x76\x65\x72\x73\x65\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x72\x65\x71\x75\x65\x73\x74\x20\x27"
.$request)."\x27\x2e"));return ((0x08f8+ 5513-0x1e81));}sub callback{(my $fd=
shift (@_));(my $uuid=$monitorFD{$fd});my ($buffer);(my $bytes=main::nxread ($fd
,(\$buffer),65536));if (($bytes>(0x1a50+ 1247-0x1f2f))){Logger::warning (((((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x61\x64\x20\x27"
.$buffer).
"\x27\x20\x66\x72\x6f\x6d\x20\x74\x68\x65\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x27"
).$uuid)."\x27\x20\x46\x44\x23").$fd)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x27"
.$uuid)."\x27\x20\x63\x6c\x6f\x73\x65\x64\x20\x46\x44\x23").$fd)."\x2e"));
Common::NXSelector::removeFromGlobalSelector ($fd);main::nxclose ($fd);if ((
$monitor{$uuid}!=$fd)){Logger::debug (
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x4e\x65\x77\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x72\x75\x6e\x6e\x69\x6e\x67\x2e"
);return ((0x0f55+ 5527-0x24ec));}__setUnreachable ($uuid);($monitor{$uuid}=
undef);($monitorFD{$fd}=undef);delete ($monitor{$uuid});delete ($monitorFD{$fd})
;if ((not (NXServerDaemon::isTerminateMode ()))){
NXConnectionMonitor::propagateMap ();}}}sub checkStatus{(my $uuid=shift (@_));(my $connection
=$monitor{$uuid});if (defined ($monitor{$uuid})){Logger::debug (((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$uuid).
"\x27\x20\x69\x73\x20\x63\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x77\x69\x74\x68\x20\x46\x44"
).$connection)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$uuid).
"\x27\x20\x69\x6e\x20\x6e\x6f\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x65\x64\x2e"))
;__setUnreachable ($uuid);}}sub __setUnreachable{(my $uuid=shift (@_));(my (
@keys)=());(my (@args)=$uuid);(my $timeout=(-(0x1c96+ 1534-0x2293)));
main::nxrequire ("\x4e\x58\x52\x65\x64\x69\x73\x53\x63\x72\x69\x70\x74");return 
(NXRedisScript::executeScript (
"\x73\x65\x74\x55\x6e\x72\x65\x61\x63\x68\x61\x62\x6c\x65",(\@keys),(\@args),
$timeout));}return ((0x0026+ 9481-0x252e));
